==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/WindowsSecurityContextOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class WindowsSecurityContextOptionsFluentImpl<A extends io.fabric8.kubernetes.api.model.WindowsSecurityContextOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.WindowsSecurityContextOptionsFluent<A>{
  public WindowsSecurityContextOptionsFluentImpl() {
  }
  public WindowsSecurityContextOptionsFluentImpl(io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions instance) {
    this.withGmsaCredentialSpec(instance.getGmsaCredentialSpec()); 
    this.withGmsaCredentialSpecName(instance.getGmsaCredentialSpecName()); 
    this.withHostProcess(instance.getHostProcess()); 
    this.withRunAsUserName(instance.getRunAsUserName()); 
  }
  private java.lang.String gmsaCredentialSpec;
  private java.lang.String gmsaCredentialSpecName;
  private java.lang.Boolean hostProcess;
  private java.lang.String runAsUserName;
  public java.lang.String getGmsaCredentialSpec() {
    return this.gmsaCredentialSpec;
  }
  public A withGmsaCredentialSpec(java.lang.String gmsaCredentialSpec) {
    this.gmsaCredentialSpec=gmsaCredentialSpec; return (A) this;
  }
  public java.lang.Boolean hasGmsaCredentialSpec() {
    return this.gmsaCredentialSpec != null;
  }
  
  /**
   * Method is deprecated. use withGmsaCredentialSpec instead.
   */
  @java.lang.Deprecated
  public A withNewGmsaCredentialSpec(java.lang.String arg0) {
    return (A)withGmsaCredentialSpec(new String(arg0));
  }
  public java.lang.String getGmsaCredentialSpecName() {
    return this.gmsaCredentialSpecName;
  }
  public A withGmsaCredentialSpecName(java.lang.String gmsaCredentialSpecName) {
    this.gmsaCredentialSpecName=gmsaCredentialSpecName; return (A) this;
  }
  public java.lang.Boolean hasGmsaCredentialSpecName() {
    return this.gmsaCredentialSpecName != null;
  }
  
  /**
   * Method is deprecated. use withGmsaCredentialSpecName instead.
   */
  @java.lang.Deprecated
  public A withNewGmsaCredentialSpecName(java.lang.String arg0) {
    return (A)withGmsaCredentialSpecName(new String(arg0));
  }
  public java.lang.Boolean getHostProcess() {
    return this.hostProcess;
  }
  public A withHostProcess(java.lang.Boolean hostProcess) {
    this.hostProcess=hostProcess; return (A) this;
  }
  public java.lang.Boolean hasHostProcess() {
    return this.hostProcess != null;
  }
  public java.lang.String getRunAsUserName() {
    return this.runAsUserName;
  }
  public A withRunAsUserName(java.lang.String runAsUserName) {
    this.runAsUserName=runAsUserName; return (A) this;
  }
  public java.lang.Boolean hasRunAsUserName() {
    return this.runAsUserName != null;
  }
  
  /**
   * Method is deprecated. use withRunAsUserName instead.
   */
  @java.lang.Deprecated
  public A withNewRunAsUserName(java.lang.String arg0) {
    return (A)withRunAsUserName(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WindowsSecurityContextOptionsFluentImpl that = (WindowsSecurityContextOptionsFluentImpl) o;
    if (gmsaCredentialSpec != null ? !gmsaCredentialSpec.equals(that.gmsaCredentialSpec) :that.gmsaCredentialSpec != null) return false;
    if (gmsaCredentialSpecName != null ? !gmsaCredentialSpecName.equals(that.gmsaCredentialSpecName) :that.gmsaCredentialSpecName != null) return false;
    if (hostProcess != null ? !hostProcess.equals(that.hostProcess) :that.hostProcess != null) return false;
    if (runAsUserName != null ? !runAsUserName.equals(that.runAsUserName) :that.runAsUserName != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(gmsaCredentialSpec,  gmsaCredentialSpecName,  hostProcess,  runAsUserName,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/WindowsSecurityContextOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class WindowsSecurityContextOptionsFluentImpl<A extends io.fabric8.kubernetes.api.model.WindowsSecurityContextOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.WindowsSecurityContextOptionsFluent<A>{
  public WindowsSecurityContextOptionsFluentImpl() {
  }
  public WindowsSecurityContextOptionsFluentImpl(io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions instance) {
    this.withGmsaCredentialSpec(instance.getGmsaCredentialSpec()); 
    this.withGmsaCredentialSpecName(instance.getGmsaCredentialSpecName()); 
    this.withHostProcess(instance.getHostProcess()); 
    this.withRunAsUserName(instance.getRunAsUserName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String gmsaCredentialSpec;
  private java.lang.String gmsaCredentialSpecName;
  private java.lang.Boolean hostProcess;
  private java.lang.String runAsUserName;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getGmsaCredentialSpec() {
    return this.gmsaCredentialSpec;
  }
  public A withGmsaCredentialSpec(java.lang.String gmsaCredentialSpec) {
    this.gmsaCredentialSpec=gmsaCredentialSpec; return (A) this;
  }
  public java.lang.Boolean hasGmsaCredentialSpec() {
    return this.gmsaCredentialSpec != null;
  }
  
  /**
   * Method is deprecated. use withGmsaCredentialSpec instead.
   */
  @java.lang.Deprecated
  public A withNewGmsaCredentialSpec(java.lang.String arg0) {
    return (A)withGmsaCredentialSpec(new String(arg0));
  }
  public java.lang.String getGmsaCredentialSpecName() {
    return this.gmsaCredentialSpecName;
  }
  public A withGmsaCredentialSpecName(java.lang.String gmsaCredentialSpecName) {
    this.gmsaCredentialSpecName=gmsaCredentialSpecName; return (A) this;
  }
  public java.lang.Boolean hasGmsaCredentialSpecName() {
    return this.gmsaCredentialSpecName != null;
  }
  
  /**
   * Method is deprecated. use withGmsaCredentialSpecName instead.
   */
  @java.lang.Deprecated
  public A withNewGmsaCredentialSpecName(java.lang.String arg0) {
    return (A)withGmsaCredentialSpecName(new String(arg0));
  }
  public java.lang.Boolean getHostProcess() {
    return this.hostProcess;
  }
  public A withHostProcess(java.lang.Boolean hostProcess) {
    this.hostProcess=hostProcess; return (A) this;
  }
  public java.lang.Boolean hasHostProcess() {
    return this.hostProcess != null;
  }
  public java.lang.String getRunAsUserName() {
    return this.runAsUserName;
  }
  public A withRunAsUserName(java.lang.String runAsUserName) {
    this.runAsUserName=runAsUserName; return (A) this;
  }
  public java.lang.Boolean hasRunAsUserName() {
    return this.runAsUserName != null;
  }
  
  /**
   * Method is deprecated. use withRunAsUserName instead.
   */
  @java.lang.Deprecated
  public A withNewRunAsUserName(java.lang.String arg0) {
    return (A)withRunAsUserName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    WindowsSecurityContextOptionsFluentImpl that = (WindowsSecurityContextOptionsFluentImpl) o;
    if (gmsaCredentialSpec != null ? !gmsaCredentialSpec.equals(that.gmsaCredentialSpec) :that.gmsaCredentialSpec != null) return false;
    if (gmsaCredentialSpecName != null ? !gmsaCredentialSpecName.equals(that.gmsaCredentialSpecName) :that.gmsaCredentialSpecName != null) return false;
    if (hostProcess != null ? !hostProcess.equals(that.hostProcess) :that.hostProcess != null) return false;
    if (runAsUserName != null ? !runAsUserName.equals(that.runAsUserName) :that.runAsUserName != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(gmsaCredentialSpec,  gmsaCredentialSpecName,  hostProcess,  runAsUserName,  additionalProperties,  super.hashCode());
  }
  
}
